source connect.tcl

proc cb {data ev args} {
    puts $ev
    puts $args
    
#    connect_cancel [lindex $args 0]
}

proc bgerror {msg} {
    global errorInfo

    puts stderr "background error: $msg"
    puts stderr "stack trace:"
    puts stderr $errorInfo
}

pack [label .label -text Whee!]

proc whee {} {
    set fg [.label cget -foreground]
    set bg [.label cget -background]
    .label configure -foreground $bg -background $fg
    after 200 whee
}

whee
connect red.cn 3000 cb "" -max_attempts 3 -timeout 3 -attempt_wait 5

vwait forever
 
